@@ -7,6 +7,7 @@ entry_points = {
     ],
     'SCPBaseForwarder': [
         'base = ssh_proxy_server.forwarders.scp:SCPForwarder',
+        'debug_traffic = ssh_proxy_server.plugins.scp.debug_traffic:SCPDebugForwarder',
         'inject_file = ssh_proxy_server.plugins.scp.inject_file:SCPInjectFile',
         'replace_file = ssh_proxy_server.plugins.scp.replace_file:SCPReplaceFile',
         'store_file = ssh_proxy_server.plugins.scp.store_file:SCPStorageForwarder'
@@ -19,6 +20,14 @@ entry_points = {
         'replace_file = ssh_proxy_server.plugins.sftp.replace_file:SFTPProxyReplaceHandler',
         'store_file = ssh_proxy_server.plugins.sftp.store_file:SFTPHandlerStoragePlugin'
     ],
+    'ServerTunnelBaseForwarder': [
+        'base = ssh_proxy_server.forwarders.tunnel:ServerTunnelForwarder',
+        'inject = ssh_proxy_server.plugins.tunnel.injectservertunnel:InjectableServerTunnelForwarder'
+    ],
+    'ClientTunnelBaseForwarder': [
+        'base = ssh_proxy_server.forwarders.tunnel:ClientTunnelForwarder',
+        'inject = ssh_proxy_server.plugins.tunnel.injectclienttunnel:InjectableClientTunnelForwarder'
+    ],
     'BaseServerInterface': [
         'base = ssh_proxy_server.interfaces.server:ServerInterface'
     ],
