@@ -9,7 +9,7 @@ class BaseForwarder(BaseModule):
     """
 
     # Slow file transmission
-    BUF_LEN = 65536
+    BUF_LEN = 65536*100
 
     def __init__(self, session):
         super().__init__()
@@ -24,7 +24,13 @@ class BaseForwarder(BaseModule):
         raise NotImplementedError
 
     def close_session(self, channel):
-        channel.close()
+        channel.lock.acquire()
+        if not channel.closed:
+            channel.lock.release()
+            channel.close()
+        if channel.lock.locked():
+            channel.lock.release()
 
     def _closed(self, channel):
-        return channel.closed or channel.eof_received or channel.eof_sent or not channel.active
+        #return channel.closed or channel.eof_received or channel.eof_sent or not channel.active
+        return channel.closed or not channel.active
